@@ -3,13 +3,13 @@ package Alien::Build::Interpolate::Default;
 use strict;
 use warnings;
 use 5.008004;
-use base qw( Alien::Build::Interpolate );
+use parent qw( Alien::Build::Interpolate );
 use File::chdir;
 use File::Which qw( which );
 use Capture::Tiny qw( capture );
 
 # ABSTRACT: Default interpolator for Alien::Build
-our $VERSION = '2.29'; # VERSION
+our $VERSION = '2.48'; # VERSION
 
 sub _config
 {
@@ -250,7 +250,7 @@ Alien::Build::Interpolate::Default - Default interpolator for Alien::Build
 
 =head1 VERSION
 
-version 2.29
+version 2.48
 
 =head1 CONSTRUCTOR
 
@@ -446,7 +446,7 @@ Juan Julián Merelo Guervós (JJ)
 
 Joel Berger (JBERGER)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Lance Wicks (LANCEW)
 
@@ -464,6 +464,8 @@ Paul Evans (leonerd, PEVANS)
 
 Håkon Hægland (hakonhagland, HAKONH)
 
+nick nauwelaerts (INPHOBIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
