@@ -2,13 +2,14 @@ package Alien::Build::Plugin::PkgConfig::PP;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use Carp ();
 use File::Which ();
 use Env qw( @PKG_CONFIG_PATH );
 
 # ABSTRACT: Probe system and determine library or tool properties using PkgConfig.pm
-our $VERSION = '1.94'; # VERSION
+our $VERSION = '2.48'; # VERSION
 
 
 has '+pkg_name' => sub {
@@ -78,7 +79,10 @@ sub init
   $meta->register_hook(
     probe => sub {
       my($build) = @_;
+
       $build->runtime_prop->{legacy}->{name} ||= $pkg_name;
+      $build->hook_prop->{probe_class} = __PACKAGE__;
+      $build->hook_prop->{probe_instance_id} = $self->instance_id;
 
       require PkgConfig;
       my $pkg = PkgConfig->find($pkg_name);
@@ -126,50 +130,48 @@ sub init
     },
   );
 
-  my $gather = sub {
-    my($build) = @_;
-    require PkgConfig;
+  $meta->register_hook(
+    $_ => sub {
+      my($build) = @_;
+
+      return if $build->hook_prop->{name} eq 'gather_system'
+      &&        ($build->install_prop->{system_probe_instance_id} || '') ne $self->instance_id;
 
-    foreach my $name ($pkg_name, @alt_names)
-    {
       require PkgConfig;
-      my $pkg = PkgConfig->find($name, search_path => [@PKG_CONFIG_PATH]);
-      if($pkg->errmsg)
+
+      foreach my $name ($pkg_name, @alt_names)
       {
-        $build->log("Trying to load the pkg-config information from the source code build");
-        $build->log("of your package failed");
-        $build->log("You are currently using the pure-perl implementation of pkg-config");
-        $build->log("(AB Plugin is named PkgConfig::PP, which uses PkgConfig.pm");
-        $build->log("It may work better with the real pkg-config.");
-        $build->log("Try installing your OS' version of pkg-config or unset ALIEN_BUILD_PKG_CONFIG");
-        die "second load of PkgConfig.pm @{[ $name ]} failed: @{[ $pkg->errmsg ]}"
+        require PkgConfig;
+        my $pkg = PkgConfig->find($name, search_path => [@PKG_CONFIG_PATH]);
+        if($pkg->errmsg)
+        {
+          $build->log("Trying to load the pkg-config information from the source code build");
+          $build->log("of your package failed");
+          $build->log("You are currently using the pure-perl implementation of pkg-config");
+          $build->log("(AB Plugin is named PkgConfig::PP, which uses PkgConfig.pm");
+          $build->log("It may work better with the real pkg-config.");
+          $build->log("Try installing your OS' version of pkg-config or unset ALIEN_BUILD_PKG_CONFIG");
+          die "second load of PkgConfig.pm @{[ $name ]} failed: @{[ $pkg->errmsg ]}"
+        }
+        my %prop;
+        $prop{cflags}  = _cleanup scalar $pkg->get_cflags;
+        $prop{libs}    = _cleanup scalar $pkg->get_ldflags;
+        $prop{version} = $pkg->pkg_version;
+        $pkg = PkgConfig->find($name, static => 1, search_path => [@PKG_CONFIG_PATH]);
+        $prop{cflags_static} = _cleanup scalar $pkg->get_cflags;
+        $prop{libs_static}   = _cleanup scalar $pkg->get_ldflags;
+        $build->runtime_prop->{alt}->{$name} = \%prop;
+      }
+      foreach my $key (keys %{ $build->runtime_prop->{alt}->{$pkg_name} })
+      {
+        $build->runtime_prop->{$key} = $build->runtime_prop->{alt}->{$pkg_name}->{$key};
+      }
+      if(keys %{ $build->runtime_prop->{alt} } == 1)
+      {
+        delete $build->runtime_prop->{alt};
       }
-      my %prop;
-      $prop{cflags}  = _cleanup scalar $pkg->get_cflags;
-      $prop{libs}    = _cleanup scalar $pkg->get_ldflags;
-      $prop{version} = $pkg->pkg_version;
-      $pkg = PkgConfig->find($name, static => 1, search_path => [@PKG_CONFIG_PATH]);
-      $prop{cflags_static} = _cleanup scalar $pkg->get_cflags;
-      $prop{libs_static}   = _cleanup scalar $pkg->get_ldflags;
-      $build->runtime_prop->{alt}->{$name} = \%prop;
     }
-    foreach my $key (keys %{ $build->runtime_prop->{alt}->{$pkg_name} })
-    {
-      $build->runtime_prop->{$key} = $build->runtime_prop->{alt}->{$pkg_name}->{$key};
-    }
-    if(keys %{ $build->runtime_prop->{alt} } == 1)
-    {
-      delete $build->runtime_prop->{alt};
-    }
-  };
-
-  $meta->register_hook(
-    gather_system => $gather,
-  );
-
-  $meta->register_hook(
-    gather_share => $gather,
-  );
+  ) for qw( gather_system gather_share );
 
   $self;
 }
@@ -188,7 +190,7 @@ Alien::Build::Plugin::PkgConfig::PP - Probe system and determine library or tool
 
 =head1 VERSION
 
-version 1.94
+version 2.48
 
 =head1 SYNOPSIS
 
@@ -199,7 +201,7 @@ version 1.94
 
 =head1 DESCRIPTION
 
-Note: in most case you will want to use L<Alien::Build::Plugin::Download::Negotiate>
+Note: in most case you will want to use L<Alien::Build::Plugin::PkgConfig::Negotiate>
 instead.  It picks the appropriate fetch plugin based on your platform and environment.
 In some cases you may need to use this plugin directly instead.
 
@@ -211,7 +213,10 @@ L<PkgConfig> to accomplish this task.
 =head2 pkg_name
 
 The package name.  If this is a list reference then .pc files with all those package
-names must be present.
+names must be present.  The first name will be the primary and used by default once
+installed.  For the subsequent C<.pc> files you can use the
+L<Alien::Base alt method|Alien::Base/alt> to retrieve the alternate configurations
+once the L<Alien> is installed.
 
 =head2 atleast_version
 
@@ -283,7 +288,7 @@ Juan Julián Merelo Guervós (JJ)
 
 Joel Berger (JBERGER)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Lance Wicks (LANCEW)
 
@@ -299,9 +304,13 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
+nick nauwelaerts (INPHOBIA)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2019 by Graham Ollis.
+This software is copyright (c) 2011-2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
